list_packages

Function list_packages 

pub fn list_packages(path: &Path, list: &NixList) -> Result<Vec<String>>
List all package names in a list within the given file. Returns an empty vec if the list is not found (not every module has one).