git_commit

Function git_commit 

pub fn git_commit(repo: &Path, message: &str)
Stage all changes and commit in a git repo. Warns on failure instead of returning an error, since git may not be configured in all environments.