Module resolve
nex_pkg
0.25.8
Module resolve
Module Items
Structs
Enums
Functions
In crate nex_
pkg
nex_pkg
Module
resolve
Structs

Candidate
A package found in a particular source with its version.
Prompt
Result
Result of an interactive resolution prompt.
Resolve
Result
Full result of resolve(), including whether all sources were checked.
Enums

Resolution
The resolution outcome.
Where a package was found.
Functions

prompt_
resolution
Display the resolution to the user and return the chosen source. Returns None if the user cancels. When
versions_equal
is true, offers an “always use nix” option.
resolve_
with_
sources
Resolve a package using only the enabled sources for the active provider policy.